#!/bin/bash

pdbfn=$1        # input PDB file
cldir=$2        # input ContactLib directory
outfn=$3        # output score file

workdir="./bin"
dsspcmd="dssp-2-linux-amd64"


if [ "$outfn" == "" ] ; then
  echo -e "USAGE: $0 IN_PDB_FILE IN_CONTACTLIB_DIR OUT_SCORE_FILE"
  exit;
fi

if [ -d "/dev/shm" ] ; then
  tmpdir="/dev/shm/contactlib/run.$$"
else
  tmpdir="/tmp/contactlib/run.$$"
fi
rm -rf $tmpdir; mkdir -p $tmpdir

pdbid=`basename ${pdbfn%.*}`
ofprefix="$tmpdir/$pdbid"

cmd="$dsspcmd $pdbfn"
echo -e "#calling <$cmd> ..."
$cmd >$ofprefix.dssp 2>&1

cmd="$workdir/contactlib.build $pdbid $pdbfn $ofprefix.dssp 9 3 4 $ofprefix"
echo -e "#calling <$cmd> ..."
$cmd >$ofp.log 2>&1

dbtype="local"
numdim=13
cutoff=32
fnlocal="$tmpdir/$dbtype-$cutoff.raw"
for dbfn in $cldir/*.$dbtype-bin ; do
  cmd="$workdir/contactlib.search $ofprefix.$dbtype-bin $dbfn $numdim $cutoff"
  echo -e "#calling <$cmd> ..."
  $cmd >>$fnlocal 2>>$tmpdir/$dbtype-$cutoff.log
done

dbtype="remote"
numdim=8
cutoff=8
fnremote="$tmpdir/$dbtype-$cutoff.raw"
for dbfn in $cldir/*.$dbtype-bin ; do
  cmd="$workdir/contactlib.search $ofprefix.$dbtype-bin $dbfn $numdim $cutoff"
  echo -e "#calling <$cmd> ..."
  $cmd >>$fnremote 2>>$tmpdir/$dbtype-$cutoff.log
done

cmd="$workdir/contactlib.score $tmpdir/local-32.raw $tmpdir/remote-8.raw 1:8"
echo -e "#calling <$cmd> ..."
$cmd >$outfn

rm -rf $tmpdir
echo -e "done!!!"

